from setuptools import setup

setup(name='Gaussian_Binomial_1',
      version='0.2',
      description='Gaussian and Binomial distributions',
      author = 'Xu Wang',
      author_email='xu.wang.pa@gmail.com',
      packages=['Gaussian_Binomial_1'],
      zip_safe=False)
